@@ -1,5 +1,5 @@
 package Net::Async::Webservice::DHL::Exception;
-$Net::Async::Webservice::DHL::Exception::VERSION = '0.01_1';
+$Net::Async::Webservice::DHL::Exception::VERSION = '0.01_2';
 {
   $Net::Async::Webservice::DHL::Exception::DIST = 'Net-Async-Webservice-DHL';
 }
@@ -28,7 +28,7 @@ around _build_stack_trace_args => sub {
 sub as_string { "something bad happened at ". $_[0]->stack_trace->as_string }
 
 {package Net::Async::Webservice::DHL::Exception::ConfigError;
-$Net::Async::Webservice::DHL::Exception::ConfigError::VERSION = '0.01_1';
+$Net::Async::Webservice::DHL::Exception::ConfigError::VERSION = '0.01_2';
 {
   $Net::Async::Webservice::DHL::Exception::ConfigError::DIST = 'Net-Async-Webservice-DHL';
 }
@@ -49,12 +49,13 @@ $Net::Async::Webservice::DHL::Exception::ConfigError::VERSION = '0.01_1';
 }
 
 {package Net::Async::Webservice::DHL::Exception::HTTPError;
-$Net::Async::Webservice::DHL::Exception::HTTPError::VERSION = '0.01_1';
+$Net::Async::Webservice::DHL::Exception::HTTPError::VERSION = '0.01_2';
 {
   $Net::Async::Webservice::DHL::Exception::HTTPError::DIST = 'Net-Async-Webservice-DHL';
 }
  use Moo;
  extends 'Net::Async::Webservice::DHL::Exception';
+ use Try::Tiny;
 
 
  has request => ( is => 'ro', required => 1 );
@@ -66,13 +67,13 @@ $Net::Async::Webservice::DHL::Exception::HTTPError::VERSION = '0.01_1';
 
      return sprintf 'Error %sing %s: %s, at %s',
          $self->request->method,$self->request->uri,
-         $self->response->status_line,
+         (try {$self->response->status_line} catch {'no response'}),
          $self->stack_trace->as_string;
  }
 }
 
 {package Net::Async::Webservice::DHL::Exception::DHLError;
-$Net::Async::Webservice::DHL::Exception::DHLError::VERSION = '0.01_1';
+$Net::Async::Webservice::DHL::Exception::DHLError::VERSION = '0.01_2';
 {
   $Net::Async::Webservice::DHL::Exception::DHLError::DIST = 'Net-Async-Webservice-DHL';
 }
@@ -109,7 +110,7 @@ Net::Async::Webservice::DHL::Exception
 
 =head1 VERSION
 
-version 0.01_1
+version 0.01_2
 
 =head1 DESCRIPTION
 
